@@ -1,12 +1,12 @@
 package File::Prepend::Undoable;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use File::Trash::Undoable;
 
@@ -94,7 +94,7 @@ sub prepend {
                             "won't prepend twice"];
             }
         }
-        $log->info("(DRY) Prepending string to file $path ...") if $dry_run;
+        log_info("(DRY) Prepending string to file $path ...") if $dry_run;
         return [200, "File $path needs to be prepended with a string", undef,
                 {undo_actions=>[
                     ['File::Trash::Undoable::untrash', # restore original
@@ -103,7 +103,7 @@ sub prepend {
                      {path=>$path, suffix=>substr($taid,0,8)."n"}],
                 ]}];
     } elsif ($tx_action eq 'fix_state') {
-        $log->info("Prepending string to file $path ...");
+        log_info("Prepending string to file $path ...");
         my $res = File::Trash::Undoable::trash(
             -tx_action=>'fix_state', path=>$path, suffix=>substr($taid,0,8));
         return $res unless $res->[0] == 200 || $res->[0] == 304;
@@ -136,16 +136,16 @@ File::Prepend::Undoable - Prepend string to a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.04 of File::Prepend::Undoable (from Perl distribution File-Prepend-Undoable), released on 2015-09-03.
-
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
+This document describes version 0.05 of File::Prepend::Undoable (from Perl distribution File-Prepend-Undoable), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
 
-=head2 prepend(%args) -> [status, msg, result, meta]
+=head2 prepend
+
+Usage:
+
+ prepend(%args) -> [status, msg, result, meta]
 
 Prepend string to a file, with undo support.
 
@@ -178,6 +178,8 @@ file.
 Unfixable state: file does not exist or path is not a regular file (directory
 and symlink included).
 
+This function is not exported.
+
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
 
@@ -248,13 +250,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
